Logging facilities, re-exported from the workflow-log crate.
Modules
- color_
log - Trait helpers for emitting a type’s binary data as a colorized hex dump.
- impls
- Backing implementation functions invoked by the
log_*!macros to route messages to the sink, browser console, Solana log, or standard output. - levels
- Self-contained
LevelandLevelFilterdefinitions, mirroring thelogcrate for use on targets where that crate is not embedded (e.g. BPF). - prelude
- Convenient re-exports of the most commonly used logging macros, level types and console helpers for glob importing.
Macros
- log_
debug - Format and log message with
Level::Debug - log_
error - Format and log message with
Level::Error - log_
info - Format and log message with
Level::Info - log_
trace - Format and log message with
Level::Trace - log_
warn - Format and log message with
Level::Warn
Structs
- Buffer
- Write colored text to memory.
- Color
HexView - Builder wrapper around a
HexViewBuilderthat accumulates colored ranges of a hex data dump and renders them viaColorHexView::try_print. - HexView
Builder - A builder for the HexView struct.
Enums
- Level
- An enum representing the available verbosity levels of the logger.
- Level
Filter - An enum representing the available verbosity level filters of the logger.
Traits
- Colo
LogTrace - Implemented by types that can render themselves as a colorized hex dump
via
log_trace. - Sink
- A log sink trait that can be installed into the log subsystem using the [
pipe] function and will receive all log messages.
Functions
- format_
hex - Returns a string formatted as a hex data dump of the supplied slice argument.
- format_
hex_ with_ colors - Formats a hex data dump to contain color ranges
- log_
level_ enabled - Returns true if the current log level is below the
currently set
LevelFilter - set_
colors_ enabled - Enables or disables ANSI color output produced by
style. - set_
log_ level - Enable filtering of log messages using the
LevelFilter - style
- Wraps an object for formatting for styling.
- trace_
hex - Prints (using
log_trace) a data slice formatted as a hex data dump.